@@ -22,7 +22,7 @@ import commands
 import properties
 import database
 
-VERSION = "0.1.4"
+VERSION = "0.1.5"
 
 def usage(available_commands):
     USAGE = "Gitissius v%s\n\n" % VERSION
@@ -48,6 +48,13 @@ def main():
         print usage(commands.available_commands)
         sys.exit()
 
+    # check we are inside a git repo
+    try:
+        common.find_repo_root()
+    except common.GitRepoNotFound, error:
+        print error
+        sys.exit(1)
+
     if not 'gitissius' in gitshelve.git('branch'):
         # no local gitissius branch exists
         # check if there is a remote
@@ -57,11 +64,29 @@ def main():
             gitshelve.git('branch', 'gitissius', 'origin/gitissius')
 
         else:
+            # save current branch name
+            branch = gitshelve.git('name-rev', '--name-only', 'HEAD') or 'master'
+
+            # stash changes
+            try:
+                gitshelve.git('stash')
+
+            except gitshelve.GitError, error:
+                pass
+
             # create an empty repo
             gitshelve.git('symbolic-ref', 'HEAD', 'refs/heads/gitissius')
-            cwd = _common.find_repo_root()
+            cwd = common.find_repo_root()
             os.unlink(os.path.join(cwd, '.git', 'index'))
             gitshelve.git('clean', '-fdx')
+            gitshelve.git('commit', '--allow-empty', '-m', 'Initialization')
+            gitshelve.git('checkout', branch)
+
+            try:
+                gitshelve.git('stash', 'pop')
+
+            except gitshelve.GitError, error:
+                pass
 
         # open the repo now, since init was done
         common.git_repo = gitshelve.open(branch='gitissius')
